@@ -224,21 +224,21 @@ class FMPSDK:
         data = response.read().decode("utf-8")
         return json.loads(data)
 
-    def financial_statement(self):
+    def financial_statement(self, filename: str = FINANCIAL_STATEMENT_FILENAME):
         """Download company's financial statement."""
         self.__init_url_query_vars()
         self.url_path = f"financial-statements/{self.symbol}"
         self.datatype = "zip"  # Only ZIP format is supported.
-        with urlopen(self.url) as response, open(
-            FINANCIAL_STATEMENT_FILENAME, "wb"
-        ) as out_file:
-            logging.info(
-                f"Saving {self.symbol} financial statement as {FINANCIAL_STATEMENT_FILENAME}."
-            )
+        with urlopen(self.url) as response, open(filename, "wb") as out_file:
+            logging.info(f"Saving {self.symbol} financial statement as {filename}.")
             shutil.copyfileobj(response, out_file)
 
     def income_statement(
-        self, period: str = "annual", download: bool = False, limit: int = 120
+        self,
+        period: str = "annual",
+        download: bool = False,
+        limit: int = 120,
+        filename: str = INCOME_STATEMENT_FILENAME,
     ):
         """
         Query FMP API for CIncome Statement.
@@ -289,12 +289,8 @@ class FMPSDK:
         self.period = period
         if download:
             self.datatype = "csv"  # Only CSV is supported.
-            with urlopen(self.url) as response, open(
-                INCOME_STATEMENT_FILENAME, "wb"
-            ) as out_file:
-                logging.info(
-                    f"Saving {self.symbol} financial statement as {INCOME_STATEMENT_FILENAME}."
-                )
+            with urlopen(self.url) as response, open(filename, "wb") as out_file:
+                logging.info(f"Saving {self.symbol} financial statement as {filename}.")
                 shutil.copyfileobj(response, out_file)
         else:
             response = urlopen(self.url)
@@ -302,7 +298,11 @@ class FMPSDK:
             return json.loads(data)
 
     def balance_sheet_statement(
-        self, period: str = "annual", download: bool = False, limit: int = 120
+        self,
+        period: str = "annual",
+        download: bool = False,
+        limit: int = 120,
+        filename: str = BALANCE_SHEET_STATEMENT_FILENAME,
     ):
         """
         Query FMP API for Balance Sheet Statement.
@@ -366,12 +366,8 @@ class FMPSDK:
         self.period = period
         if download:
             self.datatype = "csv"  # Only CSV is supported.
-            with urlopen(self.url) as response, open(
-                BALANCE_SHEET_STATEMENT_FILENAME, "wb"
-            ) as out_file:
-                logging.info(
-                    f"Saving {self.symbol} financial statement as {BALANCE_SHEET_STATEMENT_FILENAME}."
-                )
+            with urlopen(self.url) as response, open(filename, "wb") as out_file:
+                logging.info(f"Saving {self.symbol} financial statement as {filename}.")
                 shutil.copyfileobj(response, out_file)
         else:
             response = urlopen(self.url)
@@ -379,7 +375,11 @@ class FMPSDK:
             return json.loads(data)
 
     def cash_flow_statement(
-        self, period: str = "annual", download: bool = False, limit: int = 120
+        self,
+        period: str = "annual",
+        download: bool = False,
+        limit: int = 120,
+        filename: str = CASH_FLOW_STATEMENT_FILENAME,
     ):
         """
         Query FMP API for Cash Flow Statement.
@@ -434,12 +434,8 @@ class FMPSDK:
         self.period = period
         if download:
             self.datatype = "csv"  # Only CSV is supported.
-            with urlopen(self.url) as response, open(
-                CASH_FLOW_STATEMENT_FILENAME, "wb"
-            ) as out_file:
-                logging.info(
-                    f"Saving {self.symbol} financial statement as {CASH_FLOW_STATEMENT_FILENAME}."
-                )
+            with urlopen(self.url) as response, open(filename, "wb") as out_file:
+                logging.info(f"Saving {self.symbol} financial statement as {filename}.")
                 shutil.copyfileobj(response, out_file)
         else:
             response = urlopen(self.url)
@@ -596,6 +592,89 @@ class FMPSDK:
         data = response.read().decode("utf-8")
         return json.loads(data)
 
+    def historical_stock_dividend(self):
+        """
+        Query FMP API for Historical Stock Dividends
+
+        Example:
+        https://financialmodelingprep.com/api/v3/historical-price-full/stock_dividend/AAPL?apikey=demo
+        {
+          "symbol" : "AAPL",
+          "historical" : [ {
+            "date" : "2020-08-07",
+            "label" : "August 07, 20",
+            "adjDividend" : 0.2050000000,
+            "dividend" : 0.82,
+            "recordDate" : "2020-08-10",
+            "paymentDate" : "2020-08-13",
+            "declarationDate" : "2020-07-30"
+          }, {
+            "date" : "2020-05-08",
+            "label" : "May 08, 20",
+            "adjDividend" : 0.2050000000,
+            "dividend" : 0.82,
+            "recordDate" : "2020-05-11",
+            "paymentDate" : "2020-05-14",
+            "declarationDate" : "2020-04-30"
+          }, {
+            "date" : "2020-02-07",
+            "label" : "February 07, 20",
+            "adjDividend" : 0.1925000000,
+            "dividend" : 0.77,
+            "recordDate" : "2020-02-10",
+            "paymentDate" : "2020-02-13",
+            "declarationDate" : "2020-01-28"
+          }, ... ]
+        }
+        """
+        self.__init_url_query_vars()
+        self.url_path = f"historical-price-full/stock_dividend/{self.symbol}"
+        response = urlopen(self.url)
+        data = response.read().decode("utf-8")
+        return json.loads(data)
+
+    def historical_stock_split(self):
+        """
+        Query FMP API for Historical Stock Splits
+
+        Example:
+        https://financialmodelingprep.com/api/v3/historical-price-full/stock_split/AAPL?apikey=demo
+        {
+          "symbol" : "AAPL",
+          "historical" : [ {
+            "date" : "2020-08-31",
+            "label" : "August 31, 20",
+            "numerator" : 4.00,
+            "denominator" : 1.00
+          }, {
+            "date" : "2014-06-09",
+            "label" : "June 09, 14",
+            "numerator" : 7.00,
+            "denominator" : 1.00
+          }, {
+            "date" : "2005-02-28",
+            "label" : "February 28, 05",
+            "numerator" : 2.00,
+            "denominator" : 1.00
+          }, {
+            "date" : "2000-06-21",
+            "label" : "June 21, 00",
+            "numerator" : 2.00,
+            "denominator" : 1.00
+          }, {
+            "date" : "1987-06-16",
+            "label" : "June 16, 87",
+            "numerator" : 2.00,
+            "denominator" : 1.00
+          } ]
+        }
+        """
+        self.__init_url_query_vars()
+        self.url_path = f"historical-price-full/stock_split/{self.symbol}"
+        response = urlopen(self.url)
+        data = response.read().decode("utf-8")
+        return json.loads(data)
+
     # ---------------------- URL Related methods ----------------------
     def __init_url_query_vars(self) -> None:
         """
